Load Classifier
===============

.. figure:: icons/load-classifier.png

Loads an existing classifier

Signals
-------

**Inputs**:

-  None

**Outputs**:

-  **Classifier**

   A classifier with selected parameters.

Description
-----------

.. figure:: images/LoadClassifier-stamped.png

1. Choose from a list of previously used classifiers.

2. Browse for saved classifiers.

3. Reload the selected classifier.

Example
-------

When you want to use a custom-set classifier that you've saved before,
open the **Load Classifier** widget and select the desired file with the
*Browse* icon. This widget loads the exisiting classifier into
:doc:`Predictions <../evaluation/predictions>` widget for predicting classes.

.. figure:: images/LoadClassifier-example.png
